# llm-kelt Documentation

| Document | Description |
|----------|-------------|
| [Specification](spec/README.md) | Framework design and architecture |
| [Usage](usage.md) | API usage and code examples |
| [Glossary](glossary.md) | Term definitions |
